use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;

set_spell_cmd('aspell list');
add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
CPAN
github
stopwords
wordlist
makeashorterlink
makealongerlink
ua
Michiel
Beijen
michielb
Chase
Whitener
capoeirab
lib
WWW
Shorten
5gp
